@@ -88,7 +88,7 @@ class CommonAPI(GenericAPI):
         if severity is None:
             severity = self.BugSeverity.MEDIUM
         assert isinstance(severity, self.BugSeverity)
-        
+
         # Report the bug.
         url = f"{self._base_url}/api/common/user_incident/"
         data = {
@@ -104,7 +104,7 @@ class CommonAPI(GenericAPI):
             data=data,
             headers=self._auth.get_headers(),
             cookies=self._auth.get_cookies(),
-            verify=False,
+            verify=self.auth.verify,
         )
 
         if r.status_code < ERROR_THRESHOLD:
@@ -119,7 +119,7 @@ class CommonAPI(GenericAPI):
             url=url,
             headers=self._auth.get_headers(),
             cookies=self._auth.get_cookies(),
-            verify=False,
+            verify=self.auth.verify,
         )
         if r.status_code < ERROR_THRESHOLD:
             return r.json()
@@ -133,7 +133,7 @@ class CommonAPI(GenericAPI):
             url=url,
             headers=self._auth.get_headers(),
             cookies=self._auth.get_cookies(),
-            verify=False,
+            verify=self.auth.verify,
         )
         if r.status_code < ERROR_THRESHOLD:
             return r.json()
