@@ -15,8 +15,7 @@ class InvalidMetadataFormatException(Exception):
 
 def get_active_path(path):
     """Get a path that can be used to get a file size, read/write a file, etc."""
-    if platform.system() != 'Windows':
+    if platform.system() != 'Windows' or path.startswith(WINDOWS_PATH_PREFIX):
         return path
 
-    path = path.lstrip(WINDOWS_PATH_PREFIX)
     return f'{WINDOWS_PATH_PREFIX}{path}'.replace(PATH_SEP, os.path.sep)
